4.23. umbra.components.factory.scriptEditor.workers — Umbra 1.0.9 documentation

# 4.23. umbra.components.factory.scriptEditor.workers

models.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Workers.

Others:

## 4.23.1. Module Attributes

`umbra.components.factory.scriptEditor.workers.` `LOGGER`

## 4.23.2. Classes

class `umbra.components.factory.scriptEditor.workers.` `Occurence`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  Defines a storage object for the `Search_worker` class search occurence.

  Initializes the class.

  Parameters: | **kwargs (dict) – line, column, length, text.

class `umbra.components.factory.scriptEditor.workers.` `SearchResult`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  Defines a storage object for the `Search_worker` class search result.

  Initializes the class.

  Parameters: | **kwargs (dict) – file, pattern, settings, occurrences.

class `umbra.components.factory.scriptEditor.workers.` `CacheData`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  Defines a storage object for the `Search_worker` class cache data.

  Initializes the class.

  Parameters: | **kwargs (dict) – content, document.

class `umbra.components.factory.scriptEditor.workers.` `Search_worker`(parent, pattern=None, location=None, settings=None)

  Bases: `PyQt4.QtCore.QThread`

  Defines a QThread subclass used to search for a pattern in a directory files.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent.

  `searchFinished`

    This signal is emited by the `Search_worker` class when the search is finished. ( pyqtSignal )

    Returns: | Search results.
    Return type: | list

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject

  `pattern`

    Property for self.__pattern attribute.

    Returns: | self.__pattern.
    Return type: | unicode

  `location`

    Property for self.__location attribute.

    Returns: | self.__location.
    Return type: | Location

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | Location

  `searchResults`

    Property for self.__searchResults attribute.

    Returns: | self.__searchResults.
    Return type: | list

  `run`()

    Reimplements the `QThread.run()` method.

  `quit`()

    Reimplements the `QThread.quit()` method.